#!/bin/bash
#Uninstall

PRODUCT=FlashphonerWebCallServerOAM

VERSION=`cat /usr/local/$PRODUCT/conf/WCS.version`
FLASHPHONER_OAM_HOME=/usr/local/$PRODUCT
FLASHPHONER_OAM_HOME_1=/usr/local/$PRODUCT-$VERSION
INSTALL_LOG=$FLASHPHONER_OAM_HOME/bin/install.log
PRODUCT_CONFIG=$FLASHPHONER_OAM_HOME/conf/server.properties
PRODUCT_VERSION_FILE=$FLASHPHONER_OAM_HOME/conf/WCS.version
SERVER_ID_FILE=$FLASHPHONER_OAM_HOME/conf/flashphoner.serverid

OAM_PID='FlashphonerWebCallServer.pid'

function show_confirmation(){
    echo "Are you sure you want to uninstall $PRODUCT?"
    echo "Enter 'yes' or press Ctrl+C to exit."
    read confirm < /dev/tty    
    if [ "$confirm" != "yes" ]; then
	show_confirmation
    fi
}

function disable_on_startup {
 if [[ `ps --no-headers -o comm 1` == 'systemd' ]]; then
  systemctl disable wcs_oam
  rm -rf /etc/systemd/system/wcs_oam.service
 else 
  if [ -f /proc/version ]; then
    if grep -e "Red Hat\|centos" /proc/version > /dev/null; then
      chkconfig --del wcs_oam
      rm -rf /etc/init.d/wcs_oam
    elif grep -e "[Dd]ebian\|[Uu]buntu" /proc/version > /dev/null; then
      update-rc.d -f wcs_oam remove
      rm -rf /etc/init.d/wcs_oam
    fi    
  else 
    echo "Unable to determine your distribution name"
  fi
 fi  
}

function check_server_state {
 if [[ -f /var/run/$WCS_PID && $(pgrep -F /var/run/$WCS_PID) ]]; then
  echo -e "\nStopping $PRODUCT before uninstall\n"
  if [[ `ps --no-headers -o comm 1` == 'systemd' ]]; then
   systemctl stop wcs_oam
  else 
   service wcs_oam stop
  fi  
  if [[ -f /var/run/$WCS_PID && $(pgrep -F /var/run/$WCS_PID) ]]; then
   echo -e "Service did not stop, stopping application\n"
   $FLASHPHONER_OAM_HOME/bin/wcs_oam stop
  fi
 fi
}

echo "**************************************************"
echo "*                                                *"
echo "*             Uninstalling Flashphoner           *"
echo "*                                                *"
echo "* (c) Flashphoner.com 2013. All rights reserved  *"
echo "*                                                *"
echo "**************************************************"
echo ""                                                                                                           


show_confirmation
check_server_state

echo "UNINSTALLING Flashphoner..."
echo ""

disable_on_startup

echo "Removing $PRODUCT files accordingly to install.log..."
if [ -f $INSTALL_LOG ]; then
cat $INSTALL_LOG | while read line; do
    if [ -f $line ]; then
	rm -rf $line
    fi
done
fi
echo "- Removing old files completed."

cd /

rm -f $FLASHPHONER_OAM_HOME

echo ""
echo "***************************************************************************"
echo "*                                                                         *"
echo "*                         Uninstallation complete!                        *"
echo "*                                                                         *"
echo "*  Thank you for trying Flashphoner!                                      *"
echo "*  Please restart server before further work                               *"
echo "*  Support - support@flashphoner.com, forum - www.flashphoner.com/forums  *"
echo "*  Press Enter to continue                                                *"
echo "*                                                                         *"
echo "***************************************************************************"
echo ""

read cont < /dev/tty